@@ -111,7 +111,7 @@ outlyingPlotIC <- function(data,
          devIC <- data.frame(t(evIC[1:dimevIC,,drop=FALSE]))
          CMcd <- PosSemDefSymmMatrix(rrcov::getCov(rrcov::CovMcd(devIC,alpha=0.5)))
          asVar <- CMcd
-#         asVar <- solve(CMcd)
+#         asVar <- distr::solve(CMcd)
 #         cat("\n", sep="", gettext("Robust asVar"), ":\n")
 #         print(asVar)
       }
@@ -129,8 +129,8 @@ outlyingPlotIC <- function(data,
                    }
        }
     
-#       asVar <- PosSemDefSymmMatrix(solve(asVar))
-       mc$dist.x <- QFNorm(name = gettext("Mahalonobis-Norm"), QuadForm = PosSemDefSymmMatrix(solve(asVar)))
+#       asVar <- PosSemDefSymmMatrix(distr::solve(asVar))
+       mc$dist.x <- QFNorm(name = gettext("Mahalonobis-Norm"), QuadForm = PosSemDefSymmMatrix(distr::solve(asVar)))
       }
 
      if(missing(dist.y)){
@@ -144,8 +144,8 @@ outlyingPlotIC <- function(data,
             devIC <- data.frame(t(evIC[1:dimevIC,,drop=FALSE]))
             CMcd <- PosSemDefSymmMatrix(rrcov::getCov(rrcov::CovMcd(devIC,alpha=0.5)))
             asVar <- CMcd
-            cat("Fall 1\n\n")
-            print(asVar)
+#            cat("Fall 1\n\n")
+#            print(asVar)
           }
        }else{
             if("asCov" %in% names(Risks(IC.y)))
@@ -156,12 +156,12 @@ outlyingPlotIC <- function(data,
                    }
                 else{asVar <- getRiskIC(IC.y, risk = asCov())$asCov$value
                    }
-            cat("Fall 2\n\n")
-            print(asVar)
+#            cat("Fall 2\n\n")
+#            print(asVar)
        }
      
           mc$dist.y <- QFNorm(name = gettext("Mahalonobis-Norm"), 
-                              QuadForm =  PosSemDefSymmMatrix(solve(asVar)))
+                              QuadForm =  PosSemDefSymmMatrix(distr::solve(asVar)))
      }
 
 
